WakeupSource

Enum WakeupSource 

pub enum WakeupSource {
    Ext1 = 1,
    Gpio = 2,
    WifiBeacon = 3,
    Timer = 4,
    Wifi = 5,
    Uart0 = 6,
    Uart1 = 7,
    Sdio = 8,
    Uart2 = 9,
    Bt = 10,
    LpCore = 11,
}
A source that can wake the chip from sleep.

Each variant models a single bit in the wakeup registers. This enum is the internal representation shared by [WakeTriggers][crate::rtc_cntl::sleep::WakeTriggers] (the sources configured to end a sleep) and WakeupReason (the source(s) that caused the most recent wakeup, see wakeup_cause).

Note that the available variants depend on the target chip.

Variants



Ext1 = 1

EXT1 wakeup, via one or more RTC GPIOs (RTC_CNTL).



Gpio = 2

GPIO wakeup.



WifiBeacon = 3

Wi-Fi beacon wakeup.



Timer = 4

Timer wakeup.



Wifi = 5

Wi-Fi (MAC) wakeup.



Uart0 = 6

UART0 wakeup.



Uart1 = 7

UART1 wakeup.



Sdio = 8

SDIO wakeup.



Uart2 = 9

UART2 wakeup.



Bt = 10

Bluetooth wakeup.



LpCore = 11

LP core wakeup.